diff code_part1/OSTC_code_asm_part1/aa_wordprocessor.asm @ 681:6e456a6398e0

Hardware4 support
author heinrichsweikamp
date Fri, 25 Jan 2013 18:00:49 +0100
parents bde83cac971f
children 55983c4d6b2d
line wrap: on
line diff
--- a/code_part1/OSTC_code_asm_part1/aa_wordprocessor.asm	Fri Jan 25 16:31:22 2013 +0100
+++ b/code_part1/OSTC_code_asm_part1/aa_wordprocessor.asm	Fri Jan 25 18:00:49 2013 +0100
@@ -332,7 +332,7 @@
 		bra		aa_decode_12
 
 		movff	aa_temp+0,PRODH         ; Add color/2 if bit set.
-		movff	aa_temp+1,PRODL         ; OLED is big endian, so swap here.
+		movff	aa_temp+1,PRODL         ; DISPLAY is big endian, so swap here.
 aa_decode_12:
 		btfss	aa_color_quart,ACCESS
 		bra		aa_decode_3
@@ -360,12 +360,14 @@
 
 		; WHITE pixel (ie. full color)
 		movff	win_color1,PRODH	    ; current draw color
-		movff	win_color2,PRODL	    ; (rem: OLED is big endian)
+		movff	win_color2,PRODL	    ; (rem: DISPLAY is big endian)
+        setf    win_color3
 		bra		aa_decode_3
 
 aa_decode_2:
 		clrf	PRODH,A				    ; BLACK pixel
 		clrf	PRODL,A
+        clrf    win_color3
 
 aa_decode_3:
 		;---- PIXEL WRITE LOOP -----------------------------------------------
@@ -387,7 +389,7 @@
 ;------------------------------------------------------------------------------
 ; Setup pointers for a char:
 ; Inputs : letter : string to print (SHOULD BE NULL TERMINATED)
 ; Output : OLED commands on port D + clocks.
 ; 
         global  aa_wordprocessor        ; Callable from C-code.
 aa_wordprocessor:
@@ -395,7 +397,7 @@
 		movlb	HIGH win_top            ; Switch to bank 0...
 
 		rcall	aa_string_width		    ; Set win_height, compute win_width
-		rcall	PLED_box_write		    ; Use that for the box.
+		call	DISP_box_write		    ; Use that for the box.
 
 		; Restart the loop for each char to print
 		lfsr	FSR2, letter		    ; FSR2 pointer to start of string.
@@ -387,7 +389,7 @@
 ; Setup pointers for a char:
 ; Inputs : letter : string to print (SHOULD BE NULL TERMINATED)
-; Output : OLED commands on port D + clocks.
+; Output : DISPLAY commands on port D + clocks.
 ; 
         global  aa_wordprocessor        ; Callable from C-code.